==> lms-1.8.0rc5.tar.gz: lms/modules/daemonconfigadd.php <==
<?php

/*
 * LMS version 1.8.0rc5 Rosha
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: daemonconfigadd.php,v 1.6.2.1 2005/12/07 08:56:21 alec Exp $
 */

if($config = $_POST['config']) 
{
	foreach($config as $idx => $key)
		$config[$idx] = trim($key);
	
	$config['instanceid'] = $_GET['id'];
	
	if($config['var']=='' && $config['description']=='' && $config['value']=='')
	{
		$SESSION->redirect('?m=daemoninstanceview&id='.$config['instanceid']);
	}
	
	if($config['var'] == '')
		$error['var'] = trans('Option name is required!');
	elseif($DB->GetOne('SELECT id FROM daemonconfig WHERE var=? AND instanceid=?', array($config['var'], $config['instanceid'])))
		$error['var'] = trans('Option with specified name exists in that instance!');
	
	if(!$error)
	{
		$config['value'] = str_replace("\r\n","\n",$config['value']);
		
		$DB->Execute('INSERT INTO daemonconfig (var, instanceid, description, value) VALUES (?,?,?,?)',
				    array($config['var'], 
					    $config['instanceid'], 
					    $config['description'],
					    $config['value']));
		$LMS->SetTS('daemonconfig');
		
		if(!$config['reuse'])
		{
			$SESSION->redirect('?m=daemoninstanceview&id='.$config['instanceid']);
		}
		
		unset($config['var']);
		unset($config['value']);
		unset($config['description']);
	}
}	

$instance = $DB->GetRow('SELECT daemoninstances.name AS name, hosts.name AS hostname FROM daemoninstances, hosts WHERE hosts.id=hostid AND daemoninstances.id=?', array($_GET['id']));

$layout['pagetitle'] = trans('New Option for Instance: $0/$1', $instance['name'], $instance['hostname']);

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('error', $error);
$SMARTY->assign('instanceid', $_GET['id']);
$SMARTY->assign('config', $config);
$SMARTY->display('daemonconfigadd.html');

?>

==> lms-1.10.2.tar.gz: lms/modules/daemonconfigadd.php <==
<?php

/*
 * LMS version 1.10.2 Roham
 *
 *  (C) Copyright 2001-2007 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: daemonconfigadd.php,v 1.11.2.1 2007/08/17 13:15:22 alec Exp $
 */

$config = isset($_POST['config']) ? $_POST['config'] : NULL;

if($config) 
{
	foreach($config as $idx => $key)
		$config[$idx] = trim($key);
	
	$config['instanceid'] = $_GET['id'];
	
	if($config['var']=='' && $config['description']=='' && $config['value']=='')
	{
		$SESSION->redirect('?m=daemoninstanceview&id='.$config['instanceid']);
	}
	
	if($config['var'] == '')
		$error['var'] = trans('Option name is required!');
	elseif($DB->GetOne('SELECT id FROM daemonconfig WHERE var=? AND instanceid=?', array($config['var'], $config['instanceid'])))
		$error['var'] = trans('Option with specified name exists in that instance!');
	
	if(!$error)
	{
		$config['value'] = str_replace("\r\n","\n",$config['value']);
		
		$DB->Execute('INSERT INTO daemonconfig (var, instanceid, description, value) VALUES (?,?,?,?)',
				    array($config['var'], 
					    $config['instanceid'], 
					    $config['description'],
					    $config['value']));
		
		if(!isset($config['reuse']))
		{
			$SESSION->redirect('?m=daemoninstanceview&id='.$config['instanceid']);
		}
		
		unset($config['var']);
		unset($config['value']);
		unset($config['description']);
	}
}	

$instance = $DB->GetRow('SELECT daemoninstances.name AS name, hosts.name AS hostname FROM daemoninstances, hosts WHERE hosts.id=hostid AND daemoninstances.id=?', array($_GET['id']));

$layout['pagetitle'] = trans('New Option for Instance: $0/$1', $instance['name'], $instance['hostname']);

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('error', $error);
$SMARTY->assign('instanceid', $_GET['id']);
$SMARTY->assign('config', $config);
$SMARTY->display('daemonconfigadd.html');

?>
